@@ -22,7 +22,7 @@ import util
 from bitcoin import *
 
 
-class Blockchain():
+class Blockchain(util.PrintError):
     '''Manages blockchain headers and their verification'''
     def __init__(self, config, network):
         self.config = config
@@ -31,9 +31,6 @@ class Blockchain():
         self.local_height = 0
         self.set_local_height()
 
-    def print_error(self, *msg):
-        util.print_error("[blockchain]", *msg)
-
     def height(self):
         return self.local_height
 
@@ -47,17 +44,21 @@ class Blockchain():
         prev_header = self.read_header(first_header.get('block_height') -1)
 
         for header in chain:
-
             height = header.get('block_height')
-
             prev_hash = self.hash_header(prev_header)
+            if prev_hash != header.get('prev_block_hash'):
+                self.print_error("prev hash mismatch: %s vs %s"
+                                 % (prev_hash, header.get('prev_block_hash')))
+                return False
             bits, target = self.get_target(height/2016, chain)
+            if bits != header.get('bits'):
+                self.print_error("bits mismatch: %s vs %s"
+                                 % (bits, header.get('bits')))
+                return False
             _hash = self.hash_header(header)
-            try:
-                assert prev_hash == header.get('prev_block_hash')
-                assert bits == header.get('bits')
-                assert int('0x'+_hash,16) < target
-            except Exception:
+            if int('0x'+_hash, 16) > target:
+                self.print_error("insufficient proof of work: %s vs target %s"
+                                 % (int('0x'+_hash, 16), target))
                 return False
 
             prev_header = header
